@@ -1,11 +1,7 @@
 #!/usr/bin/python
 """Fills opcodes in scavenger-opcm.h"""
 
-import sys
-sys.path.append("../../")
-
-from Pyrametros.cfile import CFile
-from Pyrametros.parser import Row, parse_file
+from pyrametros import CFile, Row, parse_file
 
 # Parse the table
 grid = parse_file('testtable.txt')
